#!/usr/local/opt/python/bin/python3.7
import os
import shutil
import click


@click.command()
@click.option('--project_name', prompt='请输入项目名称', help='项目名称')
@click.option('--target_dir', default='.', help='项目存放路径')
def rf_init(project_name, target_dir):
    if not os.path.exists(target_dir):
        os.makedirs(target_dir)
        click.echo(f'目标路径 {target_dir} 不存在，现已创建成功！')
    project_dir = os.path.join(target_dir, project_name)
    if os.path.exists(project_dir):
        click.echo(f'项目名称 {project_name} 在目标路径 {target_dir} 已存在，无需重复初始化！')
    else:
        os.mkdir(project_dir)
        keyword = os.path.join(project_dir, 'keyword')
        pages = os.path.join(project_dir, 'pages')
        testcases = os.path.join(project_dir, 'testcases')
        reports = os.path.join(project_dir, 'reports')
        lib = os.path.join(project_dir, 'lib')
        children_dir = [keyword, pages, testcases, reports, lib]
        [os.mkdir(dir) for dir in children_dir]
        resource_dir = os.path.join(os.path.abspath(
            os.path.dirname(__file__)), 'resource')
        for f in os.listdir(resource_dir):
            src_path = os.path.join(resource_dir, f)
            dst_path = os.path.join(project_dir, f)
            shutil.copyfile(src_path, dst_path)
        click.echo(f'项目名称 {project_name} 在目标路径 {target_dir} 初始化成功！')


if __name__ == '__main__':
    rf_init()



import setuptools

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name="robotframework-init",
    version="0.0.5",
    author="YuWeiPeng",
    author_email="404051211@qq.com",
    description="""
    robotframework_init, is a scaffolding which can help you install most robot framework need,
    and it can create a empty project。
    robotframework_init 是一个脚手架工具，通过它可以帮你安装大部分常用的 robot framework需要的包，
    且会生成一个统一文档结构。
    """,
    # py_modules=['robotframework-init'],
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="http://www.cnblogs.com/yicaifeitian/",
    packages=setuptools.find_packages(),
    classifiers=["Programming Language :: Python :: 3",
                 "License :: OSI Approved :: MIT License",
                 "Operating System :: OS Independent", ]

    ,
    python_requires='>=3.6',
    install_requires=[
        'click>=6.7',
        'selenium>=3.141.0',
        'requests>=2.24.0',
        'robotframework >= 3.1.1',
        'robotframework-seleniumlibrary >= 3.3.1',
        'robotframework-requests >=0.7.0',
        'webdriver-manager >=3.1.0',
        'robotframework-lint >= 1.1.0',
    ]
)